@@ -1,6 +1,4 @@
-//! [`std::process::Command`][Command] customized for testing.
-//!
-//! [Command]: std::process::Command
+//! [`std::process::Command`] customized for testing.
 
 use std::ffi;
 use std::io;
@@ -17,9 +15,7 @@ use crate::output::OutputError;
 use crate::output::OutputOkExt;
 use crate::output::OutputResult;
 
-/// [`std::process::Command`][Command] customized for testing.
-///
-/// [Command]: std::process::Command
+/// [`std::process::Command`] customized for testing.
 #[derive(Debug)]
 pub struct Command {
     cmd: process::Command,
@@ -41,6 +37,8 @@ impl Command {
     ///
     /// See the [`cargo` module documentation][crate::cargo] for caveats and workarounds.
     ///
+    /// **NOTE:** Prefer [`cargo_bin!`][crate::cargo::cargo_bin!] as this makes assumptions about cargo
+    ///
     /// # Examples
     ///
     /// ```rust,no_run
@@ -119,7 +117,7 @@ impl Command {
         Ok(self.write_stdin(buffer))
     }
 
-    /// Run a `Command`, returning an [`OutputResult`][OutputResult].
+    /// Run a `Command`, returning an [`OutputResult`].
     ///
     /// # Examples
     ///
@@ -136,7 +134,7 @@ impl Command {
         OutputOkExt::ok(self)
     }
 
-    /// Run a `Command`, unwrapping the [`OutputResult`][OutputResult].
+    /// Run a `Command`, unwrapping the [`OutputResult`].
     ///
     /// # Examples
     ///
@@ -152,7 +150,7 @@ impl Command {
         OutputOkExt::unwrap(self)
     }
 
-    /// Run a `Command`, unwrapping the error in the [`OutputResult`][OutputResult].
+    /// Run a `Command`, unwrapping the error in the [`OutputResult`].
     ///
     /// # Examples
     ///
@@ -188,9 +186,7 @@ impl Command {
     }
 }
 
-/// Mirror [`std::process::Command`][Command]'s API
-///
-/// [Command]: std::process::Command
+/// Mirror [`std::process::Command`]'s API
 impl Command {
     /// Constructs a new `Command` for launching the program at
     /// path `program`, with the following default configuration:
@@ -450,12 +446,8 @@ impl Command {
         input: Option<Vec<u8>>,
         timeout: Option<std::time::Duration>,
     ) -> io::Result<process::Output> {
-        let stdin = input.and_then(|i| {
-            child
-                .stdin
-                .take()
-                .map(|mut stdin| std::thread::spawn(move || stdin.write_all(&i)))
-        });
+        #![allow(clippy::unwrap_used)] // changes behavior in some tests
+
         fn read<R>(mut input: R) -> std::thread::JoinHandle<io::Result<Vec<u8>>>
         where
             R: Read + Send + 'static,
@@ -465,6 +457,13 @@ impl Command {
                 input.read_to_end(&mut ret).map(|_| ret)
             })
         }
+
+        let stdin = input.and_then(|i| {
+            child
+                .stdin
+                .take()
+                .map(|mut stdin| std::thread::spawn(move || stdin.write_all(&i)))
+        });
         let stdout = child.stdout.take().map(read);
         let stderr = child.stderr.take().map(read);
 
@@ -503,6 +502,102 @@ impl Command {
 
         self.cmd.spawn()
     }
+
+    /// Returns the path to the program that was given to [`Command::new`].
+    ///
+    /// # Examples
+    ///
+    /// Basic usage:
+    ///
+    /// ```rust
+    /// use assert_cmd::Command;
+    ///
+    /// let cmd = Command::new("echo");
+    /// assert_eq!(cmd.get_program(), "echo");
+    /// ```
+    pub fn get_program(&self) -> &ffi::OsStr {
+        self.cmd.get_program()
+    }
+
+    /// Returns an iterator of the arguments that will be passed to the program.
+    ///
+    /// This does not include the path to the program as the first argument;
+    /// it only includes the arguments specified with [`Command::arg`] and
+    /// [`Command::args`].
+    ///
+    /// # Examples
+    ///
+    /// Basic usage:
+    ///
+    /// ```rust
+    /// use std::ffi::OsStr;
+    /// use assert_cmd::Command;
+    ///
+    /// let mut cmd = Command::new("echo");
+    /// cmd.arg("first").arg("second");
+    /// let args: Vec<&OsStr> = cmd.get_args().collect();
+    /// assert_eq!(args, &["first", "second"]);
+    /// ```
+    pub fn get_args(&self) -> process::CommandArgs<'_> {
+        self.cmd.get_args()
+    }
+
+    /// Returns an iterator of the environment variables explicitly set for the child process.
+    ///
+    /// Environment variables explicitly set using [`Command::env`], [`Command::envs`], and
+    /// [`Command::env_remove`] can be retrieved with this method.
+    ///
+    /// Note that this output does not include environment variables inherited from the parent
+    /// process.
+    ///
+    /// Each element is a tuple key/value pair `(&OsStr, Option<&OsStr>)`. A [`None`] value
+    /// indicates its key was explicitly removed via [`Command::env_remove`]. The associated key for
+    /// the [`None`] value will no longer inherit from its parent process.
+    ///
+    /// An empty iterator can indicate that no explicit mappings were added or that
+    /// [`Command::env_clear`] was called. After calling [`Command::env_clear`], the child process
+    /// will not inherit any environment variables from its parent process.
+    ///
+    /// # Examples
+    ///
+    /// Basic usage:
+    ///
+    /// ```rust
+    /// use std::ffi::OsStr;
+    /// use assert_cmd::Command;
+    ///
+    /// let mut cmd = Command::new("ls");
+    /// cmd.env("TERM", "dumb").env_remove("TZ");
+    /// let envs: Vec<(&OsStr, Option<&OsStr>)> = cmd.get_envs().collect();
+    /// assert_eq!(envs, &[
+    ///     (OsStr::new("TERM"), Some(OsStr::new("dumb"))),
+    ///     (OsStr::new("TZ"), None)
+    /// ]);
+    /// ```
+    pub fn get_envs(&self) -> process::CommandEnvs<'_> {
+        self.cmd.get_envs()
+    }
+
+    /// Returns the working directory for the child process.
+    ///
+    /// This returns [`None`] if the working directory will not be changed.
+    ///
+    /// # Examples
+    ///
+    /// Basic usage:
+    ///
+    /// ```rust
+    /// use std::path::Path;
+    /// use assert_cmd::Command;
+    ///
+    /// let mut cmd = Command::new("ls");
+    /// assert_eq!(cmd.get_current_dir(), None);
+    /// cmd.current_dir("/bin");
+    /// assert_eq!(cmd.get_current_dir(), Some(Path::new("/bin")));
+    /// ```
+    pub fn get_current_dir(&self) -> Option<&path::Path> {
+        self.cmd.get_current_dir()
+    }
 }
 
 impl From<process::Command> for Command {
@@ -511,7 +606,7 @@ impl From<process::Command> for Command {
     }
 }
 
-impl<'c> OutputOkExt for &'c mut Command {
+impl OutputOkExt for &mut Command {
     fn ok(self) -> OutputResult {
         let output = self.output().map_err(OutputError::with_cause)?;
         if output.status.success() {
@@ -550,12 +645,12 @@ impl<'c> OutputOkExt for &'c mut Command {
     }
 }
 
-impl<'c> OutputAssertExt for &'c mut Command {
+impl OutputAssertExt for &mut Command {
     fn assert(self) -> Assert {
         let output = match self.output() {
             Ok(output) => output,
             Err(err) => {
-                panic!("Failed to spawn {:?}: {}", self, err);
+                panic!("Failed to spawn {self:?}: {err}");
             }
         };
         let assert = Assert::new(output).append_context("command", format!("{:?}", self.cmd));
